@@ -8,7 +8,7 @@ use Mojo::Base -base;
 use Mojo::Loader qw(data_section);
 use Text::Xslate ();
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 $VERSION = eval $VERSION;
 
 has 'xslate';
@@ -83,7 +83,7 @@ sub _render {
         }
     }
 
-    return;
+    return 1;   # return value needed for Mojolicious <= 6.32
 }
 
 
